@@ -26,7 +26,7 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
  * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
@@ -66,19 +66,44 @@ import java.util.ListResourceBundle;
 public class FormatData_it_CH extends ListResourceBundle {
     @Override
     protected final Object[][] getContents() {
-        final String[] metaValue_java_time_buddhist_DatePatterns = new String[] {
-               "EEEE, d MMMM y G",
-               "d MMMM y G",
-               "d MMM y G",
-               "dd.MM.yy GGGGG",
-            };
-        final String[] metaValue_buddhist_DatePatterns = new String[] {
-               "EEEE, d MMMM y GGGG",
-               "d MMMM y GGGG",
-               "d MMM y GGGG",
-               "dd.MM.yy G",
-            };
+        final String[] metaValue_java_time_generic_DatePatterns = new String[] {
+            "EEEE, d MMMM y G",
+            "d MMMM y G",
+            "d MMM y G",
+            "dd.MM.yy GGGGG",
+        };
+        final String[] metaValue_generic_DatePatterns = new String[] {
+            "EEEE, d MMMM y GGGG",
+            "d MMMM y GGGG",
+            "d MMM y GGGG",
+            "dd.MM.yy G",
+        };
         final Object[][] data = new Object[][] {
+            { "java.time.generic.DatePatterns", metaValue_java_time_generic_DatePatterns },
+            { "generic.DatePatterns", metaValue_generic_DatePatterns },
+            { "DatePatterns",
+                new String[] {
+                    "EEEE, d MMMM y",
+                    "d MMMM y",
+                    "d MMM y",
+                    "dd.MM.yy",
+                }
+            },
+            { "java.time.buddhist.DatePatterns", metaValue_java_time_generic_DatePatterns },
+            { "buddhist.DatePatterns", metaValue_generic_DatePatterns },
+            { "java.time.japanese.DatePatterns", metaValue_java_time_generic_DatePatterns },
+            { "japanese.DatePatterns",
+                new String[] {
+                    "EEEE, d MMMM yyyy GGGG",
+                    "d MMMM yyyy GGGG",
+                    "d MMM y GGGG",
+                    "dd.MM.yy G",
+                }
+            },
+            { "java.time.roc.DatePatterns", metaValue_java_time_generic_DatePatterns },
+            { "roc.DatePatterns", metaValue_generic_DatePatterns },
+            { "java.time.islamic.DatePatterns", metaValue_java_time_generic_DatePatterns },
+            { "islamic.DatePatterns", metaValue_generic_DatePatterns },
             { "latn.NumberElements",
                 new String[] {
                     ".",
@@ -96,28 +121,12 @@ public class FormatData_it_CH extends ListResourceBundle {
                     "",
                 }
             },
-            { "japanese.DatePatterns", metaValue_buddhist_DatePatterns },
-            { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
-            { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
-            { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
-            { "java.time.japanese.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "latn.NumberPatterns",
                 new String[] {
                     "#,##0.###",
                     "\u00a4\u00a0#,##0.00;\u00a4-#,##0.00",
                     "#,##0%",
-                    "#,##0.00\u00a0\u00a4",
-                }
-            },
-            { "java.time.islamic.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
-            { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
-            { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
-            { "DatePatterns",
-                new String[] {
-                    "EEEE, d MMMM y",
-                    "d MMMM y",
-                    "d MMM y",
-                    "dd.MM.yy",
+                    "",
                 }
             },
         };
